@@ -28,4 +28,6 @@ is($objectc->number, 100, "Object C is good");
 
 my $objectd = MyApp->new_or_matching(identity => 'Yours');
 
-is($objectc->number, 100, "Object D is good");
+is($objectd->number, 100, "Object D is good");
+
+1;
